@@ -1,7 +1,7 @@
 package Devel::Chitin::OpTree::BINOP;
 use base 'Devel::Chitin::OpTree::UNOP';
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use strict;
 use warnings;
@@ -186,11 +186,25 @@ sub pp_leaveloop {
     if ($enterloop->op->name eq 'enteriter') {
         return $self->_deparse_foreach;
 
+    } elsif ($enterloop->op->name eq 'entergiven') {
+        return $self->_deparse_given;
+
     } else {
         return $self->_deparse_while_until;
     }
 }
 
+sub _deparse_given {
+    my $self = shift;
+
+    my $enter_op = $self->first;
+    my $topic_op = $enter_op->first;
+    my $topic = $topic_op->deparse;
+    my $block_content = $topic_op->sibling->deparse(omit_braces => 1);
+
+    "given ($topic) {$block_content}";
+}
+
 sub _deparse_while_until {
     my $self = shift;
 
@@ -348,9 +362,7 @@ sub pp_aelem {
 
 sub pp_smartmatch {
     my $self = shift;
-    if ($self->op->flags & B::OPf_SPECIAL) {
-        $self->last->deparse;
-    }
+    $self->last->deparse;
 }
 
 sub pp_lslice {
@@ -436,5 +448,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2016, Anthony Brummett.  This module is free software. It may
+Copyright 2017, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
